@@ -1,9 +1,8 @@
 package HTML::FormHandler::Field::Text;
 # ABSTRACT: text field
-
+$HTML::FormHandler::Field::Text::VERSION = '0.40068';
 use Moose;
 extends 'HTML::FormHandler::Field';
-our $VERSION = '0.01';
 
 has 'size' => ( isa => 'Int|Undef', is => 'rw', default => '0' );
 has 'maxlength' => ( isa => 'Int|Undef', is => 'rw' );
@@ -19,6 +18,7 @@ has '+widget' => ( default => 'Text' );
 our $class_messages = {
     'text_maxlength' => 'Field should not exceed [quant,_1,character]. You entered [_2]',
     'text_minlength' => 'Field must be at least [quant,_1,character]. You entered [_2]',
+    'multiple_values_disallowed' => 'Field must contain a single value',
 };
 
 sub get_class_messages {
@@ -34,12 +34,21 @@ sub get_class_messages {
     return $messages;
 }
 
+sub _inner_validate_field {
+    my $self = shift;
+    # Check for multiple values
+    if ( ref $self->value eq 'ARRAY' ) {
+        return $self->add_error(
+            $self->get_message('multiple_values_disallowed'),
+        );
+    }
+}
 
 sub validate {
     my $field = shift;
 
     return unless $field->next::method;
-    my $value = $field->input;
+    my $value = $field->value;
     # Check for max length
     if ( my $maxlength = $field->maxlength ) {
         return $field->add_error( $field->get_message('text_maxlength'),
@@ -74,7 +83,7 @@ HTML::FormHandler::Field::Text - text field
 
 =head1 VERSION
 
-version 0.40057
+version 0.40068
 
 =head1 DESCRIPTION
 
@@ -112,7 +121,7 @@ FormHandler Contributors - see HTML::FormHandler
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gerda Shank.
+This software is copyright (c) 2017 by Gerda Shank.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
