@@ -1,8 +1,9 @@
 package HTML::FormHandler::Render::RepeatableJs;
 # ABSTRACT: role providing method to construct repeatable javascript
+$HTML::FormHandler::Render::RepeatableJs::VERSION = '0.40068';
 use Moose::Role;
 
-use JSON ('encode_json');
+use JSON::MaybeXS ('encode_json');
 
 
 sub render_repeatable_js {
@@ -79,7 +80,7 @@ HTML::FormHandler::Render::RepeatableJs - role providing method to construct rep
 
 =head1 VERSION
 
-version 0.40064
+version 0.40068
 
 =head1 SYNOPSIS
 
@@ -153,7 +154,7 @@ FormHandler Contributors - see HTML::FormHandler
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gerda Shank.
+This software is copyright (c) 2017 by Gerda Shank.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
